Package: RNAdecay
Date: 2023-10-25
Title: Maximum Likelihood Decay Modeling of RNA Degradation Data
Version: 1.33.0
Authors@R: c(person("Reed", "Sorenson", email = "reedssorenson@gmail.com", role = c("aut", "cre"),comment=c(ORCID="0000-0001-8650-0601")), person("Katrina", "Johnson", email = "kjohnson@math.utah.edu", role = c("aut")),person("Frederick", "Adler", email = "adler@math.utah.edu", role = c("aut")),person("Leslie", "Sieburth", email = "sieburth@biology.utah.edu", role = c("aut"),comment=c(ORCID="0000-0001-6691-2000")))
Description: RNA degradation is monitored through measurement of RNA abundance after inhibiting RNA synthesis. This package has functions and example scripts to facilitate (1) data normalization, (2) data modeling using constant decay rate or time-dependent decay rate models, (3) the evaluation of treatment or genotype effects, and (4) plotting of the data and models. Data Normalization:  functions and scripts make easy the normalization to the initial (T0) RNA abundance, as well as a method to correct for artificial inflation of Reads per Million (RPM) abundance in global assessments as the total size of the RNA pool decreases. Modeling: Normalized data is then modeled using maximum likelihood to fit parameters. For making treatment or genotype comparisons (up to four), the modeling step models all possible treatment effects on each gene by repeating the modeling with constraints on the model parameters (i.e., the decay rate of treatments A and B are modeled once with them being equal and again allowing them to both vary independently). Model Selection: The AICc value is calculated for each model, and the model with the lowest AICc is chosen. Modeling results of selected models are then compiled into a single data frame. Graphical Plotting: functions are provided to easily visualize decay data model, or half-life distributions using ggplot2 package functions.
Depends: R (>= 4.3)
Imports: stats, grDevices, grid, ggplot2, gplots, utils, TMB, nloptr,
        scales
Suggests: parallel, knitr, reshape2, rmarkdown
biocViews: ImmunoOncology, Software, GeneExpression, GeneRegulation,
        DifferentialExpression, Transcription, Transcriptomics,
        TimeCourse, Regression, RNASeq, Normalization, WorkflowStep
License: GPL-2
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/RNAdecay
git_branch: devel
git_last_commit: 03eeb94
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-29 00:52:35 UTC; biocbuild
Author: Reed Sorenson [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8650-0601>),
  Katrina Johnson [aut],
  Frederick Adler [aut],
  Leslie Sieburth [aut] (ORCID: <https://orcid.org/0000-0001-6691-2000>)
Maintainer: Reed Sorenson <reedssorenson@gmail.com>
