# Generated by roxygen2: do not edit by hand

export(a_high)
export(a_low)
export(aic)
export(aicc)
export(b_low)
export(cols)
export(comb_cv)
export(const_decay)
export(constraint_fun_list_maker)
export(decay_plot)
export(decaying_decay)
export(fit_var)
export(group_map)
export(groupings)
export(hl_plot)
export(log_lik)
export(mod_optimization)
export(n_par)
export(plain_theme)
export(sse_null_const_decay)
export(sse_null_decaying_decay)
useDynLib(general_Exp_1sse)
useDynLib(general_Exp_2sse)
useDynLib(general_Exp_3sse)
useDynLib(general_Exp_4sse)
useDynLib(general_dExp_1sse)
useDynLib(general_dExp_2sse)
useDynLib(general_dExp_3sse)
useDynLib(general_dExp_4sse)
