% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Example_RPMs.R
\docType{data}
\name{RPMs}
\alias{RPMs}
\title{RNA abundance reads per million over RNA decay timecourse}
\format{
a data frame with 118 rows and 128 columns; data are all RNA abundance values presented as reads per million. Column names indicate genotype, time point, and replicate number separated by underscores.
}
\source{
Sorenson et al. (2017) Submitted; \url{https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE86361}
}
\usage{
RPMs
}
\description{
A dataset of RNA abundance of 118 genes in four Arabidopsis thaliana genotypes (WT, sov, vcs, vcs sov). Four biological replicates were collectred 0, 7.5, 15, 30, 60, 120, 240, 480 min after blocking transcription. RNA was extracted, subjected to ribodepletion, and sequenced by RNA-seq (Illumina 50 nt single end reads).
}
\keyword{datasets}
